@@ -28,13 +28,8 @@
 #include <gio/gio.h>
 #include <colord-private.h>
 
-#ifdef HAVE_UDEV
 #include <gudev/gudev.h>
-#endif
-
-#ifdef HAVE_GUSB
 #include <gusb.h>
-#endif
 
 #include "cd-common.h"
 
@@ -71,24 +66,21 @@ gboolean	 cd_sensor_register_object	(CdSensor		*sensor,
 						 GDBusConnection	*connection,
 						 GDBusInterfaceInfo	*info,
 						 GError			**error);
-#ifdef HAVE_UDEV
 gboolean	 cd_sensor_set_from_device	(CdSensor		*sensor,
 						 GUdevDevice		*device,
 						 GError			**error);
 GUdevDevice	*cd_sensor_get_device		(CdSensor		*sensor);
-#endif
 void		 cd_sensor_set_index		(CdSensor		*sensor,
 						 guint			 idx);
-#ifdef HAVE_GUSB
 GUsbDevice	*cd_sensor_open_usb_device	(CdSensor		*sensor,
 						 gint			 config,
 						 gint			 interface,
 						 GError			**error);
-#endif
 void		 cd_sensor_button_pressed	(CdSensor		*sensor);
 gboolean	 cd_sensor_dump			(CdSensor		*sensor,
 						 GString		*data,
 						 GError			**error);
+gboolean	 cd_sensor_get_is_embedded	(CdSensor		*sensor);
 CdSensorKind	 cd_sensor_get_kind		(CdSensor		*sensor);
 void		 cd_sensor_set_kind		(CdSensor		*sensor,
 						 CdSensorKind		 kind);
